#! /usr/bin/env node
import commandLineArgs from "command-line-args";
import commandLineUsage from "command-line-usage";
import fs from "node:fs";
import Path from "node:path";
import process from "node:process";
import Readline from "node:readline";
import { globcat } from "./globcat.js";
import "glob";
import "node:stream";
import "node:fs/promises";
const optionList = [
  {
    name: "src",
    alias: "s",
    type: String,
    multiple: true,
    defaultOption: true,
    description: "The source file globs"
  },
  {
    name: "output",
    alias: "o",
    type: String,
    description: "The file to write the output to"
  },
  {
    name: "help",
    alias: "h",
    type: Boolean,
    description: "Display this help text"
  }
];
const usage = [
  {
    header: "globcat",
    content: "Concatenate files from command line with glob pattern."
  },
  {
    header: "Options",
    optionList
  }
];
const options = commandLineArgs(optionList);
if (options["help"]) {
  process.stdout.write(commandLineUsage(usage) + "\n");
} else {
  _combine(options).catch((error) => {
    throw error;
  });
}
function _makeWriteFunction(options2) {
  return function(results) {
    if (options2["output"]) {
      const file = fs.createWriteStream(
        Path.join(process.cwd(), options2["output"])
      );
      results.pipe(file);
    } else {
      results.pipe(process.stdout);
    }
  };
}
function _makeExecFunction(options2) {
  const write = _makeWriteFunction(options2);
  return async (patterns) => {
    const content = await globcat(patterns, { stream: true });
    write(content);
  };
}
async function _combine(options2) {
  const exec = _makeExecFunction(options2);
  const patterns = options2["src"];
  if (patterns) {
    await exec(patterns);
  } else {
    const lines = [];
    const rl = Readline.createInterface({
      input: process.stdin,
      output: process.stdout,
      terminal: false
    });
    rl.on("line", (line) => lines.push(line));
    rl.on("close", () => {
      exec(lines).catch((error) => {
        throw error;
      });
    });
  }
}
